var indexSectionsWithContent =
{
  0: "abcdefghiklmnopqrstuvwx~",
  1: "abcdeinopqrstu",
  2: "cmq",
  3: "abcdegiopqrstux",
  4: "abcdefghiklmnopqrstuvw~",
  5: "abcdefhilnprstuw",
  6: "isuv",
  7: "dnu",
  8: "abcdeimnsuw",
  9: "abcdeimnoprstuv",
  10: "cs",
  11: "abcdeilqst",
  12: "abcdilnq"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "properties",
  10: "related",
  11: "defines",
  12: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Properties",
  10: "Friends",
  11: "Macros",
  12: "Pages"
};

